@@ -26,8 +26,8 @@ describe 'openstack_extras::auth_file' do
           'export OS_AUTH_URL=\'http://127.0.0.1:5000/v3/\'',
           'export OS_AUTH_STRATEGY=\'keystone\'',
           'export OS_REGION_NAME=\'RegionOne\'',
-          'export OS_PROJECT_DOMAIN_NAME=\'default\'',
-          'export OS_USER_DOMAIN_NAME=\'default\'',
+          'export OS_PROJECT_DOMAIN_NAME=\'Default\'',
+          'export OS_USER_DOMAIN_NAME=\'Default\'',
           'export OS_INTERFACE=\'public\'',
           'export OS_ENDPOINT_TYPE=\'publicURL\'',
           'export CINDER_ENDPOINT_TYPE=\'publicURL\'',
@@ -61,8 +61,8 @@ describe 'openstack_extras::auth_file' do
           :neutron_endpoint_type    => 'internalURL',
           :auth_strategy            => 'no_auth',
           :path                     => '/path/to/file',
-          :user_domain              => 'anotherdomain',
-          :project_domain           => 'anotherdomain',
+          :user_domain_name         => 'anotherdomain',
+          :project_domain_name      => 'anotherdomain',
           :compute_api_version      => '2.1',
           :network_api_version      => '2.0',
           :image_api_version        => '2',
