@@ -12,10 +12,9 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :mode   => '0644',
         :before => 'Anchor[openstack_extras_redhat]',
       )}
-
       it { should contain_yumrepo('rdo-release').with(
-        :baseurl         => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}-stream/cloud/$basearch/openstack-victoria/",
-        :descr           => "OpenStack Victoria Repository",
+        :baseurl         => "http://mirror.stream.centos.org/SIGs/$stream/cloud/$basearch/openstack-yoga/",
+        :descr           => "OpenStack Yoga Repository",
         :gpgkey          => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud',
         :enabled         => '1',
         :gpgcheck        => '1',
@@ -25,27 +24,12 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :require         => 'Anchor[openstack_extras_redhat]',
       )}
 
-      it { should contain_yumrepo('rdo-qemu-ev').with_ensure('absent') }
-
       it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization').with(
-        :source => 'puppet:///modules/openstack_extras/RPM-GPG-KEY-CentOS-SIG-Virtualization',
-        :owner  => 'root',
-        :group  => 'root',
-        :mode   => '0644',
-        :before => 'Anchor[openstack_extras_redhat]',
-      )}
-
+        :ensure => 'absent'
+      ) }
       it { should contain_yumrepo('centos-advanced-virt').with(
-        :baseurl         => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}-stream/virt/$basearch/advancedvirt-common/",
-        :descr           => "CentOS-#{facts[:operatingsystemmajrelease]}-stream - Advanced Virt",
-        :gpgkey          => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization',
-        :enabled         => '1',
-        :gpgcheck        => '1',
-        :mirrorlist      => 'absent',
-        :module_hotfixes => true,
-        :notify          => 'Exec[yum_refresh]',
-        :require         => 'Anchor[openstack_extras_redhat]',
-      )}
+        :ensure => 'absent'
+      ) }
 
       it { should_not contain_file("/etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}") }
       it { should_not contain_yumrepo('epel') }
@@ -60,22 +44,10 @@ describe 'openstack_extras::repo::redhat::redhat' do
       it { should_not contain_exec('yum_update') }
     end
 
-    context 'with default parameters but puppetversion < 6.15.0' do
-      before do
-        facts.merge!( :puppetversion => '6.14.0' )
-     end
-
-     it {
-       should contain_yumrepo('rdo-release').without_module_hotfixes
-       should contain_yumrepo('centos-advanced-virt').without_module_hotfixes
-     }
-    end
-
     context 'with parameters' do
       let :params do
         {
           :manage_rdo      => false,
-          :manage_virt     => false,
           :manage_epel     => true,
           :purge_unmanaged => true,
           :package_require => true,
@@ -88,9 +60,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
       it { should_not contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud') }
       it { should_not contain_yumrepo('rdo-release') }
 
-      it { should_not contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization') }
-      it { should_not contain_yumrepo('centos-advanced-virt') }
-
       it { should contain_file("/etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}").with(
         :source => "puppet:///modules/openstack_extras/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
         :owner  => 'root',
@@ -125,25 +94,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
       )}
     end
 
-    context 'with stream is false' do
-      let :params do
-        {
-          :manage_rdo  => true,
-          :manage_virt => true,
-          :stream      => false,
-        }
-      end
-
-      it { should contain_yumrepo('rdo-release').with(
-        :baseurl => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}/cloud/\$basearch/openstack-victoria/",
-      )}
-
-      it { should contain_yumrepo('centos-advanced-virt').with(
-        :baseurl => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}/virt/\$basearch/advanced-virtualization/",
-        :descr   => "CentOS-#{facts[:operatingsystemmajrelease]} - Advanced Virt",
-      )}
-    end
-
     context 'with overridden release' do
       let :params do
         {
@@ -153,11 +103,113 @@ describe 'openstack_extras::repo::redhat::redhat' do
       end
 
       it { should contain_yumrepo('rdo-release').with(
-        :baseurl => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}-stream/cloud/\$basearch/openstack-juno/",
+        :baseurl => "http://mirror.stream.centos.org/SIGs/$stream/cloud/$basearch/openstack-juno/",
         :descr   => 'OpenStack Juno Repository',
       )}
     end
 
+    context 'with default parameters but puppetversion < 6.15.0' do
+      before do
+        facts.merge!( :puppetversion => '6.14.0' )
+     end
+
+     it {
+       should contain_yumrepo('rdo-release').without_module_hotfixes
+     }
+    end
+
+    context 'with centos_mirror_url' do
+      let :params do
+        {
+          :manage_rdo        => true,
+          :centos_mirror_url => 'http://foo.bar',
+        }
+      end
+
+      it { should contain_yumrepo('rdo-release').with(
+        :baseurl => "http://foo.bar/SIGs/$stream/cloud/$basearch/openstack-yoga/",
+      )}
+    end
+
+    context 'with repo_defaults and gpgkey_defaults' do
+      let :params do
+        {
+          :manage_rdo      => true,
+          :manage_epel     => true,
+          :repo_hash       => {
+            'CentOS-Example' => {
+              'baseurl' => 'http://example.com/$releasever/os/$basearch/',
+              'descr'   => 'CentOS-$releasever - Example',
+              'gpgkey'  => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-Example',
+            },
+          },
+          :gpgkey_hash     => {
+            '/etc/pki/rpm-gpg/RPM-GPG-KEY-Example' => {
+              'source' => 'puppet:///modules/openstack_extras/RPM-GPG-KEY-Example',
+            }
+          },
+          :repo_defaults   => {
+            'proxy' => 'http://example.com:8000',
+          },
+          :gpgkey_defaults => {
+            'owner' => 'steve',
+            'force' => true,
+          },
+        }
+      end
+
+      it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud').with(
+        :owner  => 'steve',
+        :group  => 'root',
+        :mode   => '0644',
+        :force  => true,
+        :before => 'Anchor[openstack_extras_redhat]',
+      )}
+
+      it { should contain_yumrepo('rdo-release').with(
+        :enabled    => '1',
+        :gpgcheck   => '1',
+        :mirrorlist => 'absent',
+        :proxy      => 'http://example.com:8000',
+        :notify     => 'Exec[yum_refresh]',
+        :require    => 'Anchor[openstack_extras_redhat]',
+      )}
+
+      it { should contain_file("/etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}").with(
+        :owner  => 'steve',
+        :group  => 'root',
+        :mode   => '0644',
+        :force  => true,
+        :before => 'Anchor[openstack_extras_redhat]',
+      )}
+
+      it { should contain_yumrepo('epel').with(
+        :enabled    => '1',
+        :gpgcheck   => '1',
+        :mirrorlist => 'absent',
+        :proxy      => 'http://example.com:8000',
+        :notify     => 'Exec[yum_refresh]',
+        :require    => 'Anchor[openstack_extras_redhat]',
+      )}
+
+      it { should contain_yumrepo('CentOS-Example').with(
+        :enabled    => '1',
+        :gpgcheck   => '1',
+        :mirrorlist => 'absent',
+        :proxy      => 'http://example.com:8000',
+        :notify     => 'Exec[yum_refresh]',
+        :require    => 'Anchor[openstack_extras_redhat]',
+      )}
+
+      it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-Example').with(
+        :owner  => 'steve',
+        :group  => 'root',
+        :mode   => '0644',
+        :force  => true,
+        :before => 'Anchor[openstack_extras_redhat]',
+      )}
+    end
+
     context 'with overridden repo_hash and gpgkey_hash' do
       let :params do
         {
@@ -254,121 +306,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :notify  => 'Exec[yum_refresh]',
       )}
     end
-
-    context 'with centos_mirror_url' do
-      let :params do
-        {
-          :manage_rdo        => true,
-          :manage_virt       => true,
-          :centos_mirror_url => 'http://foo.bar',
-        }
-      end
-
-      it { should contain_yumrepo('rdo-release').with(
-        :baseurl => "http://foo.bar/centos/#{facts[:operatingsystemmajrelease]}-stream/cloud/\$basearch/openstack-victoria/",
-      )}
-
-      it { should contain_yumrepo('centos-advanced-virt').with(
-        :baseurl => "http://foo.bar/centos/#{facts[:operatingsystemmajrelease]}-stream/virt/\$basearch/advancedvirt-common/",
-      )}
-    end
-
-    context 'with repo_defaults and gpgkey_defaults' do
-      let :params do
-        {
-          :manage_rdo      => true,
-          :manage_virt     => true,
-          :manage_epel     => true,
-          :repo_hash       => {
-            'CentOS-Example' => {
-              'baseurl' => 'http://example.com/$releasever/os/$basearch/',
-              'descr'   => 'CentOS-$releasever - Example',
-              'gpgkey'  => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-Example',
-            },
-          },
-          :gpgkey_hash     => {
-            '/etc/pki/rpm-gpg/RPM-GPG-KEY-Example' => {
-              'source' => 'puppet:///modules/openstack_extras/RPM-GPG-KEY-Example',
-            }
-          },
-          :repo_defaults   => {
-            'proxy' => 'http://example.com:8000',
-          },
-          :gpgkey_defaults => {
-            'owner' => 'steve',
-            'force' => true,
-          },
-        }
-      end
-
-      it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud').with(
-        :owner  => 'steve',
-        :group  => 'root',
-        :mode   => '0644',
-        :force  => true,
-        :before => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_yumrepo('rdo-release').with(
-        :enabled    => '1',
-        :gpgcheck   => '1',
-        :mirrorlist => 'absent',
-        :proxy      => 'http://example.com:8000',
-        :notify     => 'Exec[yum_refresh]',
-        :require    => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization').with(
-        :owner  => 'steve',
-        :group  => 'root',
-        :mode   => '0644',
-        :force  => true,
-        :before => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_yumrepo('centos-advanced-virt').with(
-        :enabled    => '1',
-        :gpgcheck   => '1',
-        :mirrorlist => 'absent',
-        :proxy      => 'http://example.com:8000',
-        :notify     => 'Exec[yum_refresh]',
-        :require    => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_file("/etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}").with(
-        :owner  => 'steve',
-        :group  => 'root',
-        :mode   => '0644',
-        :force  => true,
-        :before => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_yumrepo('epel').with(
-        :enabled    => '1',
-        :gpgcheck   => '1',
-        :mirrorlist => 'absent',
-        :proxy      => 'http://example.com:8000',
-        :notify     => 'Exec[yum_refresh]',
-        :require    => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_yumrepo('CentOS-Example').with(
-        :enabled    => '1',
-        :gpgcheck   => '1',
-        :mirrorlist => 'absent',
-        :proxy      => 'http://example.com:8000',
-        :notify     => 'Exec[yum_refresh]',
-        :require    => 'Anchor[openstack_extras_redhat]',
-      )}
-
-      it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-Example').with(
-        :owner  => 'steve',
-        :group  => 'root',
-        :mode   => '0644',
-        :force  => true,
-        :before => 'Anchor[openstack_extras_redhat]',
-      )}
-    end
   end
 
   on_supported_os({
